@@ -72,6 +72,16 @@ class JenkinsBase(object):
             raise
         return result
 
+    def post_data(self, url, content):
+        try:
+            request = urllib2.Request(url, content)
+            result = urllib2.urlopen(request).read().strip()
+        except urllib2.HTTPError, e:
+            log.warn("Error post data %s" % url)
+            log.exception(e)
+            raise
+        return result
+
     def hit_url(self, url ):
         fn_urlopen = self.get_jenkins_obj().get_opener()
         try:
